Struct ZwlrExportDmabufManagerV1
pub struct ZwlrExportDmabufManagerV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
manager to inform clients and begin capturing
This object is a manager with which to start capturing from sources.
This interface has no events.
Implementations
impl ZwlrExportDmabufManagerV1
impl ZwlrExportDmabufManagerV1
pub fn capture_output<U, D>(
&self,
overlay_cursor: i32,
output: &WlOutput,
qh: &QueueHandle<D>,
udata: U,
) -> ZwlrExportDmabufFrameV1
pub fn capture_output<U, D>( &self, overlay_cursor: i32, output: &WlOutput, qh: &QueueHandle<D>, udata: U, ) -> ZwlrExportDmabufFrameV1
capture a frame from an output
Capture the next frame of an entire output.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the manager
All objects created by the manager will still remain valid, until their appropriate destroy request has been called.